==> pointpos_api-0.0.16.tar.gz: doc/LoyaltyProgramApi.md <==
# pointpos_api.api.LoyaltyProgramApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createLoyaltyprogram**](LoyaltyProgramApi.md#createLoyaltyprogram) | **Post** /loyalty-program | Create Loyaltyprogram
[**deleteLoyaltyprogramByID**](LoyaltyProgramApi.md#deleteLoyaltyprogramByID) | **Delete** /loyalty-program/:id | Delete Loyaltyprogram By ID
[**findLoyaltyprogram**](LoyaltyProgramApi.md#findLoyaltyprogram) | **Get** /loyalty-program | Get Loyaltyprogram List
[**getLoyaltyprogramByID**](LoyaltyProgramApi.md#getLoyaltyprogramByID) | **Get** /loyalty-program/:id | Get Loyaltyprogram By ID
[**updateLoyaltyprogramByID**](LoyaltyProgramApi.md#updateLoyaltyprogramByID) | **Put** /loyalty-program/:id | Update Loyaltyprogram By ID


# **createLoyaltyprogram**
> LoyaltyProgram createLoyaltyprogram(authorization, xAPIKey, body, xPin)

Create Loyaltyprogram

Create Loyaltyprogram

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new LoyaltyProgram(); // LoyaltyProgram | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createLoyaltyprogram(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->createLoyaltyprogram: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**LoyaltyProgram**](LoyaltyProgram.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**LoyaltyProgram**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteLoyaltyprogramByID**
> deleteLoyaltyprogramByID(authorization, xAPIKey, id, xPin)

Delete Loyaltyprogram By ID

Delete Loyaltyprogram By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deleteLoyaltyprogramByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->deleteLoyaltyprogramByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findLoyaltyprogram**
> List<LoyaltyProgram> findLoyaltyprogram(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter)

Get Loyaltyprogram List

Get Loyaltyprogram  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"pointFromTotalSpent\"   - \"pointFromBuyItem\"   - \"newMemberPoint\"   - \"redeemRules\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findLoyaltyprogram(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->findLoyaltyprogram: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;pointFromTotalSpent\&quot;   - \&quot;pointFromBuyItem\&quot;   - \&quot;newMemberPoint\&quot;   - \&quot;redeemRules\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<LoyaltyProgram>**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getLoyaltyprogramByID**
> LoyaltyProgram getLoyaltyprogramByID(authorization, xAPIKey, id, xPin)

Get Loyaltyprogram By ID

Get Loyaltyprogram By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getLoyaltyprogramByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->getLoyaltyprogramByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**LoyaltyProgram**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateLoyaltyprogramByID**
> LoyaltyProgram updateLoyaltyprogramByID(authorization, xAPIKey, id, body, xPin)

Update Loyaltyprogram By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new LoyaltyProgram(); // LoyaltyProgram | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updateLoyaltyprogramByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->updateLoyaltyprogramByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**LoyaltyProgram**](LoyaltyProgram.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**LoyaltyProgram**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.2.1.tar.gz: doc/LoyaltyProgramApi.md <==
# pointpos_api.api.LoyaltyProgramApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createLoyaltyprogram**](LoyaltyProgramApi.md#createLoyaltyprogram) | **Post** /loyalty-program | Create Loyaltyprogram
[**deleteLoyaltyprogramByID**](LoyaltyProgramApi.md#deleteLoyaltyprogramByID) | **Delete** /loyalty-program/:id | Delete Loyaltyprogram By ID
[**findLoyaltyprogram**](LoyaltyProgramApi.md#findLoyaltyprogram) | **Get** /loyalty-program | Get Loyaltyprogram List
[**getLoyaltyprogramByID**](LoyaltyProgramApi.md#getLoyaltyprogramByID) | **Get** /loyalty-program/:id | Get Loyaltyprogram By ID
[**updateLoyaltyprogramByID**](LoyaltyProgramApi.md#updateLoyaltyprogramByID) | **Put** /loyalty-program/:id | Update Loyaltyprogram By ID


# **createLoyaltyprogram**
> LoyaltyProgram createLoyaltyprogram(authorization, xAPIKey, body, xPin)

Create Loyaltyprogram

Create Loyaltyprogram

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new LoyaltyProgram(); // LoyaltyProgram | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createLoyaltyprogram(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->createLoyaltyprogram: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**LoyaltyProgram**](LoyaltyProgram.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**LoyaltyProgram**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteLoyaltyprogramByID**
> deleteLoyaltyprogramByID(authorization, xAPIKey, id, xPin)

Delete Loyaltyprogram By ID

Delete Loyaltyprogram By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deleteLoyaltyprogramByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->deleteLoyaltyprogramByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findLoyaltyprogram**
> List<LoyaltyProgram> findLoyaltyprogram(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted)

Get Loyaltyprogram List

Get Loyaltyprogram  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'createdAt|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"pointFromTotalSpent\"   - \"pointFromBuyItem\"   - \"newMemberPoint\"   - \"redeemRules\"   - \"createdAt\"   - \"createdBy\"   - \"updatedAt\"   - \"updatedBy\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 
var withDeleted = true; // bool | Return with deleted resource

try { 
    var result = api_instance.findLoyaltyprogram(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->findLoyaltyprogram: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;createdAt|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;pointFromTotalSpent\&quot;   - \&quot;pointFromBuyItem\&quot;   - \&quot;newMemberPoint\&quot;   - \&quot;redeemRules\&quot;   - \&quot;createdAt\&quot;   - \&quot;createdBy\&quot;   - \&quot;updatedAt\&quot;   - \&quot;updatedBy\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]
 **withDeleted** | **bool**| Return with deleted resource | [optional] [default to false]

### Return type

[**List<LoyaltyProgram>**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getLoyaltyprogramByID**
> LoyaltyProgram getLoyaltyprogramByID(authorization, xAPIKey, id, xPin)

Get Loyaltyprogram By ID

Get Loyaltyprogram By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getLoyaltyprogramByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->getLoyaltyprogramByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**LoyaltyProgram**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateLoyaltyprogramByID**
> LoyaltyProgram updateLoyaltyprogramByID(authorization, xAPIKey, id, body, xPin)

Update Loyaltyprogram By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new LoyaltyProgramApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new LoyaltyProgram(); // LoyaltyProgram | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updateLoyaltyprogramByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling LoyaltyProgramApi->updateLoyaltyprogramByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**LoyaltyProgram**](LoyaltyProgram.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**LoyaltyProgram**](LoyaltyProgram.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
